<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:template match="Computer">
    <HTML>
    
    <H1><xsl:value-of select="@Name"/></H1>

    <table width="100%" border="1">
      <tr valign="top">
        <td>CPU:</td>
        <td>
          <table width="100%" border="1">
          <xsl:apply-templates select="Processor"/>
          </table>
        </td> 
      </tr>
      <tr valign="top">
        <td>RAM:</td>
        <td>
          <table width="100%" border="1">
          <xsl:apply-templates select="MemoryDevice"/>
          <xsl:apply-templates select="PhysicalMemory"/>
          </table>
        </td> 
      </tr>
      <tr valign="top">
        <td>HDD:</td>
        <td>
          <table width="100%" border="1">
          <xsl:apply-templates select="DiskDrive"/>
          </table>
        </td> 
      </tr>  
      <tr valign="top">
        <td>Video:</td>
        <td>
          <table width="100%" border="1">
          <xsl:apply-templates select="VideoController"/>
          </table>
        </td> 
      </tr>
      <tr valign="top">
        <td>Net:</td>
        <td>
          <table width="100%" border="1">
          <xsl:apply-templates select="NetworkAdapter"/>
          </table>
        </td> 
      </tr>
      <tr valign="top">
        <td>Monitor:</td>
        <td>
          <table width="100%" border="1">
          <xsl:apply-templates select="DesktopMonitor"/>
          </table>
        </td> 
      </tr>
      <tr valign="top">
        <td>OS:</td>
        <td>
          <table width="100%" border="1">
          <xsl:apply-templates select="OperatingSystem"/>
          </table>
        </td> 
      </tr>
      <tr valign="top">
        <td>Products:</td>
        <td>
          <table width="100%" border="1">
          <xsl:apply-templates select="Product">
            <xsl:sort select="@Name"/>
          </xsl:apply-templates>
          </table>
        </td> 
      </tr>

    </table>
    </HTML>
  </xsl:template>

  <xsl:template match="Processor[position() = 1]">
    <tr>    
    <td><b>Name: </b><xsl:value-of select="@Name"/></td>
    <td><b>MaxClockSpeed: </b><xsl:value-of select="@MaxClockSpeed"/>MHz</td>
    </tr> 
  </xsl:template>

  <xsl:template match="Processor[(position() > 1) and (@SocketDesignation != ./@SocketDesignation)]">
    <tr>    
    <td>Name: <xsl:value-of select="@Name"/></td>
    <td>MaxClockSpeed: <xsl:value-of select="@MaxClockSpeed"/>MHz</td>
    </tr> 
  </xsl:template>

  <xsl:template match="MemoryDevice">
    <tr>
    <td><b>DeviceID: </b><xsl:value-of select="@DeviceID"/></td>
    <td><b>StartingAddress: </b><xsl:value-of select="@StartingAddress"/></td>
    <td><b>EndingAddress: </b><xsl:value-of select="@EndingAddress"/></td>
    <td><b>Difference: </b><xsl:value-of select="@EndingAddress - @StartingAddress"/></td>
    </tr> 
  </xsl:template>

  <xsl:template match="PhysicalMemory">
    <tr>
    <td><b>DeviceLocator: </b><xsl:value-of select="@DeviceLocator"/></td>
    <td><b>Capacity: </b><xsl:value-of select="@Capacity"/></td>
    <td><b>Speed: </b><xsl:value-of select="@Speed"/></td>
    </tr> 
  </xsl:template>

  <xsl:template match="DiskDrive">
    <tr>
    <td><b>Index: </b><xsl:value-of select="@Index"/></td>
    <td><b>InterfaceType: </b><xsl:value-of select="@InterfaceType"/></td>
    <td><b>Partitions: </b><xsl:value-of select="@Partitions"/></td>
    <td><b>Size: </b><xsl:value-of select="floor(@Size div 1024 div 1024 div 1024)"/>Gb</td>
    </tr> 
  </xsl:template>

  <xsl:template match="VideoController">
    <tr>
    <td><b>DeviceID: </b><xsl:value-of select="@DeviceID"/></td>
    <td><b>VideoProcessor: </b><xsl:value-of select="@VideoProcessor"/></td>
    <td><b>AdapterRAM: </b><xsl:value-of select="floor(@AdapterRAM div 1024 div 1024)"/>Mb</td>
    <td>
      <b>Resolution: </b>
      <xsl:value-of select="@CurrentHorizontalResolution"/>
      x
      <xsl:value-of select="@CurrentVerticalResolution"/>
      x
      <xsl:value-of select="@CurrentNumberOfColors"/>
    </td>
    </tr> 
  </xsl:template>

  <xsl:template match="NetworkAdapter[@NetConnectionStatus > 0]">
    <tr>
    <td><b>DeviceID: </b><xsl:value-of select="@DeviceID"/></td>
    <td><b>Name: </b><xsl:value-of select="@Name"/></td>
    <td><b>ServiceName: </b><xsl:value-of select="@ServiceName"/></td>
    <td><b>MAC: </b><xsl:value-of select="@MACAddress"/></td>
    <td><xsl:value-of select="@NetConnectionStatus"/></td>
    </tr> 
  </xsl:template>

  <xsl:template match="DesktopMonitor">
    <tr>
    <td><b>DeviceID: </b><xsl:value-of select="@DeviceID"/></td>
    <td><b>Name: </b><xsl:value-of select="@Name"/></td>
    </tr> 
  </xsl:template>

  <xsl:template match="OperatingSystem">
    <tr>
    <td><b>Caption: </b><xsl:value-of select="@Caption"/></td>
    <td><b>Version: </b><xsl:value-of select="@Version"/></td>
    <td><b>SerialNumber: </b><xsl:value-of select="@SerialNumber"/></td>
    <td><b>SP MajorVersion: </b><xsl:value-of select="@ServicePackMajorVersion"/></td>
    <td><b>SP MinorVersion: </b><xsl:value-of select="@ServicePackMinorVersion"/></td>
    <td><b>InstallDate: </b><xsl:value-of select="concat(substring(@InstallDate,7,2),'.',substring(@InstallDate,5,2),'.',substring(@InstallDate,1,4))"/></td>
    </tr> 
  </xsl:template>

  <xsl:template match="Product">
    <tr>
    <td><b>Caption: </b><xsl:value-of select="@Caption"/></td>
    <td><b>Version: </b><xsl:value-of select="@Version"/></td>
    </tr> 
  </xsl:template>

</xsl:stylesheet>